#!/usr/bin/env python
import click
import os

from auto_click_auto import enable_click_shell_completion
from auto_click_auto.constants import ShellType

@click.group()
@click.pass_context
def container(ctx):
    """
    \b
    Control Station
    Docker Container Operations and Deployments
    """
    pass


@container.command('deploy', short_help='Deploy Docker Container to Server')
@click.argument('host', metavar="<host>", type=click.STRING)
@click.argument('application', metavar="<application>", type=click.STRING)
@click.option('-f', '--container_config', metavar="<file>", help='Container Configuration File [US01_SYNER_US01DB]')
@click.pass_context
def deploy(ctx, host, application, container_config):
    """
        Deploy Docker Container to Server
        
        \b
        <host>: sg01.synercatalyst.com
        \b
        <application>: Application for Container
        \b
            portainer    : Portainer Application
            traefik      : Traefik Reversed Proxy
            perfectwork  : PerfectWORK 3.0 - 5.0
            perfectwork_dns : Multiple domains/databases PerfectWORK
            perfectwork6 : PerfectWORK >= 6.0
            perfectwork6_dns : Multiple domains/databases PerfectWORK
    """

    if container_config is None:
        os.system(f"ansible-playbook -l {host} /opt/cstation/ansible/container/{application}.yaml")
    else:
        os.system(f"ansible-playbook -l {host} /opt/cstation/ansible/container/{application}.yaml --extra-vars @/opt/cstation/config_file/{host}/{container_config}.yaml")


#!/usr/bin/env python

import click
import os


@click.group("odoo")
@click.pass_context
def odoo(ctx):
    """
    \b
    Control Station
    Setting Up Odoo 16 or above Repositories
    """
    pass


@odoo.command(
    "server", short_help="Configure Odoo version => 16.0 for Remote Server",  no_args_is_help=True
)
@click.argument("host", metavar="<host>", type=click.STRING)
@click.argument("version", metavar="<version>", type=click.STRING)
@click.option(
    "-p",
    "--ssh_port",
    metavar="<ssh_port>",
    default="8288",
    show_default=True,
    help="SSH Port",
)
@click.option(
    "-oa",
    "--only_addons",
    default=False,
    is_flag=True,
    show_default=True,
    help="Only Sync Addons Modules [PW_ADDONS_X.0]",
)
@click.pass_context
def server(ctx, host, version, ssh_port, only_addons):
    """
    Setting Odoo for Remote Server Operations

    \b
    <host>: Hostname in the Inventory List or local
    \b
    <version>: Odoo version => 16.0
    \b
        16.0   : Version 16.0
        17.0   : Version 17.0
    \b
    """

    click.echo(
        f"Preparing PerfectWORK Version {version} - Deploy To -> {host} using Port {ssh_port}"
    )
    # Sync the addon directory
    if only_addons:
        click.echo(
            f"Deploy PerfectWORK Addons Modules {version} To -> {host} using Port {ssh_port}"
        )
        os.system(
            f'rsync -avzhe "ssh -p{ssh_port}" --copy-links --delete --exclude  ".*" --exclude "__pycache__"  /opt/PW/Addons.{version}/ root@{host}.synercatalyst.com:/var/lib/odoo/Addons.{version}'
        )
    else:
        # No Need to prepare directory for sending the files to Remote Host
        click.echo(
            f"Preparing PerfectWORK Core Modules {version} To -> {host} using Port {ssh_port}"
        )
        os.system(
            f"rm -rf ./Odoo.{version}"
        )
        os.system(
            f"rsync -avzhe --delete --exclude  '.*' /opt/PW/Odoo.{version}/  ./Odoo.{version}"
        )
        os.system(
            f"mv ./Odoo.{version}/odoo/addons/* ./Odoo.{version}/addons/"
        )
        os.system(
            f"rm -rf ./Odoo.{version}/odoo/addons"
        )
        os.system(
            f"mv ./Odoo.{version}/addons ./Odoo.{version}/odoo/"
        )
        os.system(
            "find ./ -name __pycache__ -type d -exec rm -rf {} + "
        )
        click.echo(
            f"Deploy PerfectWORK Version {version} To -> {host} using Port {ssh_port}"
        )
        os.system(
            f"rsync -avzhe 'ssh -p{ssh_port}'  --delete --exclude  '.*'  ./Odoo.{version}/odoo/ root@{host}.synercatalyst.com:/var/lib/odoo/Odoo.{version}"
        )
        os.system(
            f"rm -rf ./Odoo.{version}"
        )
        click.echo(
            f"Deploy PerfectWORK Addons Modules {version} To -> {host} using Port {ssh_port}"
        )
        os.system(
            f'rsync -avzhe "ssh -p{ssh_port}" --copy-links --delete --exclude  ".*" --exclude "__pycache__"  /opt/PW/PW_ADDONS.{version}/ root@{host}.synercatalyst.com:/var/lib/perfectwork/PW_ADDONS.{version}'
        )

@odoo.command(
    "local", short_help="Configure Odoo for Local Host Development Operations", no_args_is_help=True
)
@click.argument("version", metavar="<version>", type=click.STRING)
@click.option(
    "-oa",
    "--only_addons",
    default=False,
    is_flag=True,
    show_default=True,
    help="Prepare Addons Modules Only for [ADDONS.X.0]",
)
@click.pass_context
def local(ctx, version, only_addons):
    """
    Setting Odoo for Localhost Operations

    \b
    <version>: Odoo version => 16.0
    \b
        16.0   : Odoo 16.0
        17.0   : Odoo 17.0

    """
    if not only_addons:
        click.echo(f"Preparing Odoo Version {version} for Local Development")
        os.chdir("/opt/PW/odoo")
        os.system(f"git switch {version}")
        os.system(
            f"rsync -avzhe --delete --exclude '.*' --exclude '__pycache__' --exclude 'odoo.conf' /opt/PW/odoo/* /opt/PW/Odoo.{version}"
        )

    # Open the file in read mode
    with open(f'/opt/PW/Addons.{version}/odoo_addons_github.yaml', 'r') as file:
        lines = file.readlines()

    # # Print the lines
    for line in lines:
        parts = line.split("/",1)
        app_name = parts[1].split(".")[0]
        os.system(f'rm -rf /opt/PW/Addons.{version}/{app_name}')
        print(f'git clone {line.strip()} --single-branch --branch {version} - {app_name}')
        os.system(f'git clone {line.strip()} --single-branch --branch {version} /opt/PW/Addons.{version}/{app_name} ')
    
    # Download modules from OCA Repositories
    os.system(
        f"gitoo install-all --conf_file /opt/PW/Addons.{version}/odoo_addons_oca.yaml --destination /opt/PW/Addons.{version}"
    )


import click

from commands import odoo
from commands import container
from commands import github
from commands import perfectwork
from commands import perfectwork6

@click.group()
@click.pass_context
@click.version_option("0.1.13", prog_name="cstation Control Station")

# @click.pass_context
def cli(ctx):
    """
    \b
    Control Station
    A wrapper around ansible for Deployment
    """
    pass

cli.add_command(odoo.odoo)
cli.add_command(container.container)
cli.add_command(perfectwork.perfectwork)
cli.add_command(perfectwork6.perfectwork6)
cli.add_command(github.github)

if __name__ == "__main__":
    cli()



#!/usr/bin/env python

import sys
import click
import os

@click.group('')
@click.pass_context
def streamlit(ctx):
    """
    \b
    Control Station
    Setting Up Streamlit Repositories
    """
    pass


@streamlit.command('server', short_help='Configure Streamlit for Remote Server')
@click.argument('host', metavar="<host>", type=click.STRING)
@click.option('-p', '--ssh_port', metavar="<ssh_port>", default="8288", show_default=True, help='SSH Port')
@click.pass_context
def server(ctx, host, ssh_port):
    """
        Setting Up Streamlit for Remote Server Operations
        
        \b
        <host>: Hostname in the Inventory List or local
        \b
    """
    
    click.echo(f'Preparing Streamlit - Deploy To -> {host} using Port {ssh_port}')
    # Sync the addon directory

    # Need to prepare directory for sending the files to Remote Host
    click.echo(f'Deploy Streamlit Core Modules to -> {host} using Port {ssh_port}')
    os.system(f'rsync -avzhe "ssh -p{ssh_port}"  --delete --exclude  ".*" --exclude "node_modules"  /opt/LLM/streamlit/* root@{host}.synercatalyst.com:/var/lib/streamlit')



#!/usr/bin/env python

import click
import os


@click.group("perfectwork6")
@click.pass_context
def perfectwork6(ctx):
    """
    \b
    Control Station
    Setting Up PerfectWORK => 6.0 Repositories
    """
    pass


@perfectwork6.command(
    "server", short_help="Configure PerfectWORK => 6.0 for Remote Server"
)
@click.argument("host", metavar="<host>", type=click.STRING)
@click.argument("version", metavar="<version>", type=click.STRING)
@click.option(
    "-p",
    "--ssh_port",
    metavar="<ssh_port>",
    default="8288",
    show_default=True,
    help="SSH Port",
)
@click.option(
    "-oa",
    "--only_addons",
    default=False,
    is_flag=True,
    show_default=True,
    help="Only Sync Addons Modules [PW_ADDONS_X.0]",
)
@click.pass_context
def server(ctx, host, version, ssh_port, only_addons):
    """
    Setting PerfectWORK for Remote Server Operations

    \b
    <host>: Full host name of the server
    \b
    sg01.synercatalyst.com
    sg01.ansis.com.sg
    \b
    <version>: Odoo version => 16.0
    \b
        6.0   : Version 16.0
        7.0   : Version 17.0
    \b
    """

    click.echo(
        f"Preparing PerfectWORK Version {version} - Deploy To -> {host} using Port {ssh_port}"
    )
    # Sync the addon directory
    if only_addons:
        click.echo(
            f"Deploy PerfectWORK Addons Modules {version} To -> {host} using Port {ssh_port}"
        )
        os.system(
            f'rsync -avzhe "ssh -p{ssh_port}" --copy-links --delete --exclude  ".*" --exclude "__pycache__"  /opt/PW/PW_ADDONS.{version}/ root@{host}:/var/lib/perfectwork/PW_ADDONS.{version}'
        )
    else:
        # No Need to prepare directory for sending the files to Remote Host
        click.echo(
            f"Preparing PerfectWORK Core Modules {version} To -> {host} using Port {ssh_port}"
        )
        os.system(
            f"rm -rf ./PW.{version}"
        )
        os.system(
            f"rsync -avzhe --delete --exclude  '.*' /opt/PW/PW.{version}/  ./PW.{version}"
        )
        os.system(
            f"mv ./PW.{version}/odoo/addons/* ./PW.{version}/addons/"
        )
        os.system(
            f"rm -rf ./PW.{version}/odoo/addons"
        )
        os.system(
            f"mv ./PW.{version}/addons ./PW.{version}/odoo/"
        )
        os.system(
            "find ./ -name __pycache__ -type d -exec rm -rf {} + "
        )
        click.echo(
            f"Deploy PerfectWORK Version {version} To -> {host} using Port {ssh_port}"
        )
        os.system(
            f"rsync -avzhe 'ssh -p{ssh_port}'  --delete --exclude  '.*'  ./PW.{version}/odoo/ root@{host}:/var/lib/perfectwork/PW.{version}"
        )
        os.system(
            f"rm -rf ./PW.{version}"
        )
        click.echo(
            f"Deploy PerfectWORK Addons Modules {version} To -> {host} using Port {ssh_port}"
        )
        os.system(
            f'rsync -avzhe "ssh -p{ssh_port}" --copy-links --delete --exclude  ".*" --exclude "__pycache__"  /opt/PW/PW_ADDONS.{version}/ root@{host}:/var/lib/perfectwork/PW_ADDONS.{version}'
        )

@perfectwork6.command(
    "local", short_help="Configure PerfectWORK for Local Development Operations"
)
@click.argument("version", metavar="<version>", type=click.STRING)
@click.option(
    "-a",
    "--with_addons",
    default=False,
    is_flag=True,
    show_default=True,
    help="Inclusive Addons Modules [PW_ADDONS]",
)
@click.pass_context
def local(ctx, version, with_addons):
    """
    Setting Odoo for Localhost Operations

    \b
    <version>: Odoo version => 6.0
    \b
        16.0   : Version 16.0
        17.0   : Version 17.0

    """

    click.echo(f"Preparing PerfectWORK Version {version} for Local Development")
    os.chdir("/opt/PW/odoo")
    os.system(f"git switch {version}")
    os.system(
        f"rsync -avzhe --delete --exclude '.*' --exclude '__pycache__' /opt/PW/odoo/* /opt/PW/Odoo.{version}"
    )



#!/usr/bin/env python

import click
import os

@click.group('')
@click.pass_context
def github(ctx):
    """
    \b
    Control Station - Managing GITHUB Account
    """
    pass


@github.command('oca_rebuild', short_help='Rebuild OCA modules from github')
@click.argument("version", metavar="<version>", type=click.STRING)
# @click.option('oca_filename', metavar="<oca_filename>", type=click.Path(exists=True))
@click.pass_context
def oca_rebuild(ctx, version):
    """
        Rebuild OCA modules from github

        \b
        <version>: Odoo version => 7.0
        \b
            6.0   : Version 16.0
            7.0   : Version 17.0
        \b        
        \b
        oca_addons.yaml in /opt/PW/PW_ADDONS.{version}/OCA directory
        \b
        File containing list of OCA repositories to build
        \b   
    """
    # Open the file in read mode
    os.system(f'gitoo install-all --conf_file /opt/PW/PW_ADDONS.{version}/OCA/oca_addons.yaml --destination /opt/PW/PW_ADDONS.{version}/OCA')
    


@github.command('repo_sync', short_help='Syncing repositories with upstream')
@click.argument('repo_filename', metavar="<repo_filename>", default='/opt/cstation/etc/github_repo.yaml', type=click.Path(exists=True))
# @click.option('-s', '--sync', is_flag=True, show_default=False, help='Syncing repositories with upstream')
@click.pass_context
def repo_sync(ctx, repo_filename):
    """
        Syncing repositories with upstream
        
        \b
        <repo_filename> : File containing list of repositories to sync
        Default File : /opt/cstation/etc/github_repo.yaml
        \b   
    """
    # Open the file in read mode
    with open(repo_filename, 'r') as file:
        lines = file.readlines()

    # # Print the lines
    for line in lines:
        if line.strip() != "":
            print(f'gh repo sync {line.strip()}')
            os.system(f'gh repo sync {line.strip()}')

    # Need to prepare directory for sending the files to Remote Host
    # click.echo (f'Deploy Streamlit Core Modules to -> {host} using Port {ssh_port}')
    # os.system(f'rsync -avzhe "ssh -p{ssh_port}"  --delete --exclude  ".*" --exclude "node_modules"  /opt/LLM/streamlit/* root@{host}.synercatalyst.com:/var/lib/streamlit
    # Need to prepare directory for sending the files to Remote Host
    # click.echo (f'Deploy Streamlit Core Modules to -> {host} using Port {ssh_port}')
    # os.system(f'rsync -avzhe "ssh -p{ssh_port}"  --delete --exclude  ".*" --exclude "node_modules"  /opt/LLM/streamlit/* root@{host}.synercatalyst.com:/var/lib/streamlit')



from setuptools import setup, find_packages

setup(
    name='cstation',
    version='0.1.13',
    py_modules=['cstation'],
    packages=find_packages(),
    url="https://github.com/ansis-ai/cstation.git",
    install_requires=[
        'Click',
    ],
    entry_points={
        'console_scripts': [
            'cstation = cstation:cli',
        ],
    },
)


#!/usr/bin/env python

import click
import os

@click.group('perfectwork')
@click.pass_context
def perfectwork(ctx):
    """
    \b
    Control Station
    Setting Up PerfectWORK Repositories
    """
    pass


@perfectwork.command('server', short_help='Configure PerfectWORK for Remote Server')
@click.argument('host', metavar="<host>", type=click.STRING)
@click.argument('version', metavar="<version>", type=click.STRING)
@click.option('-p', '--ssh_port', metavar="<ssh_port>", default="8288", show_default=True, help='SSH Port')
@click.option('-oa', '--only_addons', default=False, is_flag=True, show_default=True, help='Only Sync Addons Modules [PW_ADDONS_X.0]')
@click.pass_context
def server(ctx, host, version, ssh_port, only_addons):
    """
        Setting PerfectWORK for Remote Server Operations
        
        \b
        <host>: Hostname in the Inventory List or local
        \b
        <version>: PerfectWORK version
        \b
            5.0   : Version 5.0
            6.0   : Version 6.0
            7.0   : Version 7.0
        \b
    """
    
    click.echo(f'Preparing PerfectWORK Version {version} - Deploy To -> {host} using Port {ssh_port}')
    # Sync the addon directory
    if only_addons:
        click.echo(f'Deploy PerfectWORK Addons Modules {version} To -> {host} using Port {ssh_port}')
        os.system(f'rsync -avzhe "ssh -p{ssh_port}" --copy-links --delete --exclude  ".*" --exclude "__pycache__"  /opt/PW/PW_ADDONS.{version}/ root@{host}:/var/lib/perfectwork/PW_ADDONS.{version}')
    else:
        # Need to prepare directory for sending the files to Remote Host
        click.echo(f'Deploy PerfectWORK Core Modules {version} To -> {host} using Port {ssh_port}')
        os.system(f'rm -rf /opt/SysOps/tmp/PW.{version}')
        os.system(f'rsync -avzhe --delete --exclude ".*" --exclude "__pycache__" --exclude "*pyc" /opt/PW/PW.{version}/  /opt/SysOps/tmp/PW.{version}')
        os.system(f'mv /opt/SysOps/tmp/PW.{version}/odoo/addons/* /opt/SysOps/tmp/PW.{version}/addons/')
        os.system(f'rm -rf /opt/SysOps/tmp/PW.{version}/odoo/addons')
        os.system(f'mv /opt/SysOps/tmp/PW.{version}/addons /opt/SysOps/tmp/PW.{version}/odoo/')
        click.echo(f'Deploy PerfectWORK Version {version} To -> {host} using Port {ssh_port}')
        os.system(f'rsync -avzhe "ssh -p{ssh_port}"  --delete --exclude  ".*" --exclude "__pycache__"  /opt/SysOps/tmp/PW.{version}/odoo/ root@{host}:/var/lib/perfectwork/PW.{version}')
        # Clear the directory
        os.system(f'rm -rf /opt/SysOps/tmp/PW.{version}')
  
@perfectwork.command('local', short_help='Configure PerfectWORK for Local Development Operations')
@click.argument('version', metavar="<version>", type=click.STRING)
@click.option('-a', '--with_addons', default=False, is_flag=True, show_default=True, help='Inclusive Addons Modules [PW_ADDONS]')
@click.pass_context
def server(ctx, version, with_addons):
    """
        Setting PerfectWORK for Remote Server Operations
        
        \b
        <version>: PerfectWORK version
        \b
            5.0   : Version 5.0 
            6.0   : Version 6.0 
            7.0   : Version 7.0
            
    """

    click.echo(f'Preparing PerfectWORK Version {version} for Local Development')
    os.chdir("/opt/PW/odoo")
    os.system(f"git switch 1{version}") 
    os.system(f"rsync -avzhe --delete --exclude '.*' --exclude '__pycache__' /opt/PW/odoo/* /opt/PW/PW.{version}")
    